@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -32,9 +33,7 @@
 #include <cppuhelper/weak.hxx>
 #include <cppuhelper/component.hxx>
 #include <cppuhelper/factory.hxx>
-#ifndef _CPPUHELPER_IMPLBASE3_HXX
 #include <cppuhelper/implbase3.hxx>
-#endif
 #include <cppuhelper/typeprovider.hxx>
 #include <rtl/unload.h>
 
@@ -866,7 +865,7 @@ Reference< XInterface > ORegistryFactoryHelper::createModuleFactory()
             // one implementation found -> try to activate
             aLocation = xLocationKey->getAsciiValue();
 
-            // search protocol delemitter
+            // search protocol delimiter
             sal_Int32 nPos = aLocation.indexOf(
                 OUString( RTL_CONSTASCII_USTRINGPARAM("://") ) );
             if( nPos != -1 )
@@ -1086,8 +1085,6 @@ Reference<XSingleServiceFactory > SAL_CALL createOneInstanceFactory(
 {
     return new OFactoryComponentHelper(
         rServiceManager, rImplementationName, pCreateFunction, 0, &rServiceNames, pModCount, sal_True );
-//	return new OFactoryUnloadableComponentHelper(
-//		rServiceManager, rImplementationName, pCreateFunction, 0, &rServiceNames, pModCount, sal_True );
 }
 
 // global function
@@ -1138,3 +1135,4 @@ Reference< lang::XSingleComponentFactory > SAL_CALL createOneInstanceComponentFa
 }
 
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
