@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -30,17 +31,13 @@
 #include <osl/diagnose.h>
 #include <osl/mutex.hxx>
 #include <rtl/alloc.h>
-#ifndef _RTL_USTRBUF_H_
 #include <rtl/ustrbuf.hxx>
-#endif
 #include <cppuhelper/queryinterface.hxx>
 #include <cppuhelper/weak.hxx>
 #include <cppuhelper/factory.hxx>
 #include <cppuhelper/implbase1.hxx>
 #include <cppuhelper/implbase2.hxx>
-#ifndef _CPPUHELPER_IMPLEMENTATIONENTRY_HXX_
 #include <cppuhelper/implementationentry.hxx>
-#endif
 #include <registry/registry.hxx>
 
 #include <com/sun/star/registry/XSimpleRegistry.hpp>
@@ -1304,3 +1301,4 @@ Reference<XInterface> SAL_CALL SimpleRegistry_CreateInstance( const Reference<XC
 }
 }
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
