@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -31,13 +32,9 @@
 #include <osl/mutex.hxx>
 #include "rtl/ustrbuf.hxx"
 #include <cppuhelper/factory.hxx>
-#ifndef _CPPUHELPER_IMPLBASE5_HXX_
 #include <cppuhelper/compbase5.hxx>
-#endif
 #include <cppuhelper/implbase1.hxx>
-#ifndef _CPPUHELPER_IMPLEMENTATIONENTRY_HXX_
 #include <cppuhelper/implementationentry.hxx>
-#endif
 #include "tdmgr_common.hxx"
 #include "tdmgr_tdenumeration.hxx"
 #include "lrucache.hxx"
@@ -1161,3 +1158,4 @@ Reference< XInterface > SAL_CALL ManagerImpl_create(
 
 }
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
